
local ctn = require("containers")

local assets =
{
    Asset("ANIM", "anim/swap_equip_pack.zip"),
    Asset("ATLAS", "images/inventoryimages/equip_pack.xml"),
    Asset("IMAGE", "images/inventoryimages/equip_pack.tex"),
}

local function onequip(inst, owner)
    owner.AnimState:OverrideSymbol("swap_body", "swap_equip_pack", "backpack")
    owner.AnimState:OverrideSymbol("swap_body", "swap_equip_pack", "swap_body")
    inst.components.container:Open(owner)
end

local function onunequip(inst, owner)
    owner.AnimState:ClearOverrideSymbol("swap_body")
    owner.AnimState:ClearOverrideSymbol("backpack")
    inst.components.container:Close(owner)
end

local function onburnt(inst)
    if inst.components.container then
        inst.components.container:DropEverything()
        inst.components.container:Close()
        inst:RemoveComponent("container")
    end

    local ash = SpawnPrefab("ash")
    ash.Transform:SetPosition(inst.Transform:GetWorldPosition())

    inst:Remove()
end

local function fn()
    local inst = CreateEntity()

    inst.entity:AddTransform()
    inst.entity:AddAnimState()
    inst.entity:AddSoundEmitter()
    inst.entity:AddMiniMapEntity()
    inst.entity:AddNetwork()

    MakeInventoryPhysics(inst)

    inst.AnimState:SetBank("equip_pack")
    inst.AnimState:SetBuild("swap_equip_pack")
    inst.AnimState:PlayAnimation("anim")

    inst:AddTag("backpack")
    inst:AddTag("fridge")
    inst:AddTag("nocool")
    inst:AddTag("waterproofer")

    inst.foleysound = "dontstarve/movement/foley/backpack"

    if CurrentRelease.GreaterOrEqualTo("R08_ROT_TURNOFTIDES") then
    	MakeInventoryFloatable(inst, "small", 0.2, 0.80)
    end

    inst.entity:SetPristine()

	if not TheWorld.ismastersim then	
	inst.OnEntityReplicated = function(inst) inst.replica.container:WidgetSetup("equip_pack") end	
	return inst
	end

    inst:AddComponent("inventoryitem")

    inst.components.inventoryitem.atlasname = "images/inventoryimages/equip_pack.xml"
	
    inst.components.inventoryitem.imagename = "equip_pack"
	inst.components.inventoryitem.cangoincontainer = false
	
	
    inst.MiniMapEntity:SetIcon("minimap_equip_pack.tex")

    inst:AddComponent("equippable")
    if EQUIPSLOTS["BACK"] then
        inst.components.equippable.equipslot = EQUIPSLOTS.BACK
    elseif EQUIPSLOTS["PACK"] then
        inst.components.equippable.equipslot = EQUIPSLOTS.PACK
    else
        inst.components.equippable.equipslot = EQUIPSLOTS.BODY
    end

    inst.components.equippable:SetOnEquip( onequip )
    inst.components.equippable:SetOnUnequip( onunequip )

    inst:AddComponent("container")
	inst.components.container:WidgetSetup("equip_pack")
	

    inst:AddComponent("inspectable")
	
    inst:AddComponent("waterproofer")
    inst.components.waterproofer:SetEffectiveness(0)

    --[[
    MakeSmallBurnable(inst)
    MakeSmallPropagator(inst)
    inst.components.burnable:SetOnBurntFn(onburnt)
    ]]
    
    MakeHauntableLaunchAndDropFirstItem(inst)

    return inst
end

STRINGS.NAMES.EQUIP_PACK 				= "Equipment Pack"
STRINGS.NAMES.EQUIP_SACK                                 = "Equip Pack"
STRINGS.RECIPE_DESC.EQUIP_PACK 				= "Big, but not very spacious."

STRINGS.CHARACTERS.GENERIC.DESCRIBE.EQUIP_PACK  		= "You could fit one of everything in here!"
STRINGS.CHARACTERS.WILLOW.DESCRIBE.EQUIP_PACK  			= "It makes me feel like a girl scout again."
STRINGS.CHARACTERS.WOLFGANG.DESCRIBE.EQUIP_PACK 		= "Weight does not affect me!"
STRINGS.CHARACTERS.WENDY.DESCRIBE.EQUIP_PACK 			= "A box for trinkets."
STRINGS.CHARACTERS.WX78.DESCRIBE.EQUIP_PACK 			= "TOOL COMPARTMENT"
STRINGS.CHARACTERS.WICKERBOTTOM.DESCRIBE.EQUIP_PACK 	= "Somewhere to keep my books dry."
STRINGS.CHARACTERS.WOODIE.DESCRIBE.EQUIP_PACK 			= "I feel like hiking."
STRINGS.CHARACTERS.WAXWELL.DESCRIBE.EQUIP_PACK 			= "A toolbox for my tools."
STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.EQUIP_PACK 		= "Keeps my weapons and armour ready for battle."
STRINGS.CHARACTERS.WEBBER.DESCRIBE.EQUIP_PACK			= "It's like a toy box!"
STRINGS.CHARACTERS.WINONA.DESCRIBE.EQUIP_PACK           = "Just enough space for the essentials."
STRINGS.CHARACTERS.WORTOX.DESCRIBE.EQUIP_PACK 	        = "A pack of pockets a-plenty."
STRINGS.CHARACTERS.WORMWOOD.DESCRIBE.EQUIP_PACK         = "For fiddly stuff"
STRINGS.CHARACTERS.WARLY.DESCRIBE.EQUIP_PACK            = "A pack to keep my knives safe."


return Prefab("common/inventory/equip_pack", fn, assets)