local ctn = require("containers")

local assets =
{
	Asset("ANIM", "anim/ice_pack.zip"),
	Asset("ATLAS", "images/inventoryimages/ice_pack.xml"),
}

local function onopen(inst)
    inst.SoundEmitter:PlaySound("dontstarve/common/icebox_open")
end

local function onclose(inst)
    inst.SoundEmitter:PlaySound("dontstarve/common/icebox_close")
end
				
local function fn()
    local inst = CreateEntity()

    inst.entity:AddTransform()
    inst.entity:AddAnimState()
    inst.entity:AddSoundEmitter()
    inst.entity:AddMiniMapEntity()
    inst.entity:AddNetwork()

    MakeInventoryPhysics(inst)
	
    inst.AnimState:SetBank("ice_pack")
    inst.AnimState:SetBuild("ice_pack")
    inst.AnimState:PlayAnimation("idle")

	inst.MiniMapEntity:SetIcon("minimap_ice_pack.tex")
	
	inst:AddTag("fridge")
--    inst:AddTag("nocool")
 
    
    if CurrentRelease.GreaterOrEqualTo("R08_ROT_TURNOFTIDES") then
    	MakeInventoryFloatable(inst, "small", 0.2, 0.80)
    end

    inst.entity:SetPristine()

	if not TheWorld.ismastersim then	
	inst.OnEntityReplicated = function(inst) inst.replica.container:WidgetSetup("ice_pack") end	
	return inst
	end
   
    
    inst:AddComponent("tradable")
    inst:AddComponent("inspectable")
    
    inst:AddComponent("inventoryitem")
	inst.components.inventoryitem.imagename = "ice_pack"
	inst.components.inventoryitem.atlasname = "images/inventoryimages/ice_pack.xml"
	inst:AddComponent("container")
	inst.components.container:WidgetSetup("ice_pack")	
    inst.components.container.onopenfn = onopen
    inst.components.container.onclosefn = onclose
	
    MakeHauntableLaunchAndSmash(inst)
	
    return inst
end

STRINGS.NAMES.ICE_PACK 									= "Ice Pack"
STRINGS.RECIPE_DESC.ICE_PACK 							= "Portable Ice Box."

STRINGS.CHARACTERS.GENERIC.DESCRIBE.ICE_PACK 			= "A scientific achievement for food!"
STRINGS.CHARACTERS.WILLOW.DESCRIBE.ICE_PACK 			= "It's a tiny fridge!"
STRINGS.CHARACTERS.WOLFGANG.DESCRIBE.ICE_PACK 			= "Is small, but good for food!"
STRINGS.CHARACTERS.WENDY.DESCRIBE.ICE_PACK 				= "A cold box to match my cold heart."
STRINGS.CHARACTERS.WX78.DESCRIBE.ICE_PACK 				= "THERMALS ARE STABLE"
STRINGS.CHARACTERS.WICKERBOTTOM.DESCRIBE.ICE_PACK 		= "A mobile Ice Box to slow spoilage."
STRINGS.CHARACTERS.WOODIE.DESCRIBE.ICE_PACK 			= "Ma' food will be kept tasty."
STRINGS.CHARACTERS.WAXWELL.DESCRIBE.ICE_PACK 			= "Keeps my suit clean from carrying food around."
STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.ICE_PACK 		= "A crack into Niflheim."
STRINGS.CHARACTERS.WEBBER.DESCRIBE.ICE_PACK 			= "It's a small ice box."
STRINGS.CHARACTERS.WINONA.DESCRIBE.ICE_PACK             = "Oughta keep my lunch nice and fresh."
STRINGS.CHARACTERS.WORTOX.DESCRIBE.ICE_PACK  		    = "Chilly, chilly, nice and icy."
STRINGS.CHARACTERS.WORMWOOD.DESCRIBE.ICE_PACK           = "Cold"
STRINGS.CHARACTERS.WARLY.DESCRIBE.ICE_PACK              = "Now that is convenience."


return Prefab( "common/inventory/ice_pack", fn, assets) 
