local ctn = require("containers")

local assets =
{
    Asset("ANIM", "anim/swap_wool_sack.zip"),
    Asset("ATLAS", "images/inventoryimages/wool_sack.xml"),
    Asset("IMAGE", "images/inventoryimages/wool_sack.tex"),
}

local function onequip(inst, owner)
    owner.AnimState:OverrideSymbol("swap_body", "swap_wool_sack", "backpack")
    owner.AnimState:OverrideSymbol("swap_body", "swap_wool_sack", "swap_body")
    inst.components.container:Open(owner)
end

local function onunequip(inst, owner)
    owner.AnimState:ClearOverrideSymbol("swap_body")
    owner.AnimState:ClearOverrideSymbol("backpack")
    inst.components.container:Close(owner)
end

local function onburnt(inst)
    if inst.components.container then
        inst.components.container:DropEverything()
        inst.components.container:Close()
        inst:RemoveComponent("container")
    end

    local ash = SpawnPrefab("ash")
    ash.Transform:SetPosition(inst.Transform:GetWorldPosition())

    inst:Remove()
end

local function fn()
    local inst = CreateEntity()

    inst.entity:AddTransform()
    inst.entity:AddAnimState()
    inst.entity:AddSoundEmitter()
    inst.entity:AddMiniMapEntity()
    inst.entity:AddNetwork()

    MakeInventoryPhysics(inst)

    inst.AnimState:SetBank("wool_sack")
    inst.AnimState:SetBuild("swap_wool_sack")
    inst.AnimState:PlayAnimation("anim")

    inst:AddTag("backpack")

    inst.foleysound = "dontstarve/movement/foley/backpack"

    if CurrentRelease.GreaterOrEqualTo("R08_ROT_TURNOFTIDES") then
    	MakeInventoryFloatable(inst, "small", 0.2, 0.80)
    end

    inst.entity:SetPristine()

	if not TheWorld.ismastersim then	
	inst.OnEntityReplicated = function(inst) inst.replica.container:WidgetSetup("piggyback") end	
	return inst
	end

    inst:AddComponent("inventoryitem")
    inst.components.inventoryitem.atlasname = "images/inventoryimages/wool_sack.xml"
    inst.components.inventoryitem.imagename = "wool_sack"
	inst.components.inventoryitem.cangoincontainer = false
	
    inst.MiniMapEntity:SetIcon("minimap_wool_sack.tex")

    inst:AddComponent("equippable")
    if EQUIPSLOTS["BACK"] then
        inst.components.equippable.equipslot = EQUIPSLOTS.BACK
    elseif EQUIPSLOTS["PACK"] then
        inst.components.equippable.equipslot = EQUIPSLOTS.PACK
    else
        inst.components.equippable.equipslot = EQUIPSLOTS.BODY
    end

    inst.components.equippable:SetOnEquip( onequip )
    inst.components.equippable:SetOnUnequip( onunequip )

    inst:AddComponent("container")
	inst.components.container:WidgetSetup("piggyback")
	
    inst:AddComponent("inspectable")
	
    --[[
    MakeSmallBurnable(inst)
    MakeSmallPropagator(inst)
    inst.components.burnable:SetOnBurntFn(onburnt)
    ]]
    
    MakeHauntableLaunchAndDropFirstItem(inst)

    return inst
end

STRINGS.NAMES.WOOL_SACK                                 = "Wool Sack"
STRINGS.NAMES.WOOL_SACK                                 = "Wool Sack"
STRINGS.RECIPE_DESC.WOOL_SACK                           = "Carries a lot and does not slow you down."

STRINGS.CHARACTERS.GENERIC.DESCRIBE.WOOL_SACK           = "Feels like a steel scrubber on my back"
STRINGS.CHARACTERS.WILLOW.DESCRIBE.WOOL_SACK            = "It's like a big, metal fuzz ball."
STRINGS.CHARACTERS.WOLFGANG.DESCRIBE.WOOL_SACK          = "Is like my chest hair."
STRINGS.CHARACTERS.WENDY.DESCRIBE.WOOL_SACK             = "Not as fuzzy as it appears to be."
STRINGS.CHARACTERS.WX78.DESCRIBE.WOOL_SACK              = "METALLIC SACK MADE FROM ORGANIC MATTER."
STRINGS.CHARACTERS.WICKERBOTTOM.DESCRIBE.WOOL_SACK      = "It seems to make its contents feel lighter."
STRINGS.CHARACTERS.WOODIE.DESCRIBE.WOOL_SACK            = "A back scratcher."
STRINGS.CHARACTERS.WAXWELL.DESCRIBE.WOOL_SACK           = "Scratches any back itches away."
STRINGS.CHARACTERS.WATHGRITHR.DESCRIBE.WOOL_SACK        = "This sack is evidence of my triumphant battle!"
STRINGS.CHARACTERS.WEBBER.DESCRIBE.WOOL_SACK            = "It's like a massive scrubber!"
STRINGS.CHARACTERS.WINONA.DESCRIBE.WOOL_SACK            = "Surprisingly lightweight!"
STRINGS.CHARACTERS.WORTOX.DESCRIBE.WOOL_SACK		    = "Full of itchy stiches."
STRINGS.CHARACTERS.WORMWOOD.DESCRIBE.WOOL_SACK          = "Scratchy"
STRINGS.CHARACTERS.WARLY.DESCRIBE.WOOL_SACK             = "Scratchy on the back."


return Prefab("common/inventory/wool_sack", fn, assets)